import _slicedToArray from '@babel/runtime/helpers/esm/slicedToArray';
import { memo, useState, useEffect } from 'react';
import cc from 'classcat';
import { useStoreApi, useStore, useReactFlow, Panel } from '@reactflow/core';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import _objectWithoutProperties from '@babel/runtime/helpers/esm/objectWithoutProperties';

function PlusIcon() {
  return /*#__PURE__*/jsx("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 32 32",
    children: /*#__PURE__*/jsx("path", {
      d: "M32 18.133H18.133V32h-4.266V18.133H0v-4.266h13.867V0h4.266v13.867H32z"
    })
  });
}

function MinusIcon() {
  return /*#__PURE__*/jsx("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 32 5",
    children: /*#__PURE__*/jsx("path", {
      d: "M0 0h32v4.2H0z"
    })
  });
}

function FitViewIcon() {
  return /*#__PURE__*/jsx("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 32 30",
    children: /*#__PURE__*/jsx("path", {
      d: "M3.692 4.63c0-.53.4-.938.939-.938h5.215V0H4.708C2.13 0 0 2.054 0 4.63v5.216h3.692V4.631zM27.354 0h-5.2v3.692h5.17c.53 0 .984.4.984.939v5.215H32V4.631A4.624 4.624 0 0027.354 0zm.954 24.83c0 .532-.4.94-.939.94h-5.215v3.768h5.215c2.577 0 4.631-2.13 4.631-4.707v-5.139h-3.692v5.139zm-23.677.94c-.531 0-.939-.4-.939-.94v-5.138H0v5.139c0 2.577 2.13 4.707 4.708 4.707h5.138V25.77H4.631z"
    })
  });
}

function LockIcon() {
  return /*#__PURE__*/jsx("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 25 32",
    children: /*#__PURE__*/jsx("path", {
      d: "M21.333 10.667H19.81V7.619C19.81 3.429 16.38 0 12.19 0 8 0 4.571 3.429 4.571 7.619v3.048H3.048A3.056 3.056 0 000 13.714v15.238A3.056 3.056 0 003.048 32h18.285a3.056 3.056 0 003.048-3.048V13.714a3.056 3.056 0 00-3.048-3.047zM12.19 24.533a3.056 3.056 0 01-3.047-3.047 3.056 3.056 0 013.047-3.048 3.056 3.056 0 013.048 3.048 3.056 3.056 0 01-3.048 3.047zm4.724-13.866H7.467V7.619c0-2.59 2.133-4.724 4.723-4.724 2.591 0 4.724 2.133 4.724 4.724v3.048z"
    })
  });
}

function UnlockIcon() {
  return /*#__PURE__*/jsx("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 25 32",
    children: /*#__PURE__*/jsx("path", {
      d: "M21.333 10.667H19.81V7.619C19.81 3.429 16.38 0 12.19 0c-4.114 1.828-1.37 2.133.305 2.438 1.676.305 4.42 2.59 4.42 5.181v3.048H3.047A3.056 3.056 0 000 13.714v15.238A3.056 3.056 0 003.048 32h18.285a3.056 3.056 0 003.048-3.048V13.714a3.056 3.056 0 00-3.048-3.047zM12.19 24.533a3.056 3.056 0 01-3.047-3.047 3.056 3.056 0 013.047-3.048 3.056 3.056 0 013.048 3.048 3.056 3.056 0 01-3.048 3.047z"
    })
  });
}

var _excluded = ["children", "className"];

var ControlButton = function ControlButton(_ref) {
  var children = _ref.children,
      className = _ref.className,
      rest = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/jsx("button", _objectSpread(_objectSpread({
    type: "button",
    className: cc(['react-flow__controls-button', className])
  }, rest), {}, {
    children: children
  }));
};

ControlButton.displayName = 'ControlButton';
var ControlButton$1 = ControlButton;

var isInteractiveSelector = function isInteractiveSelector(s) {
  return s.nodesDraggable && s.nodesConnectable && s.elementsSelectable;
};

var Controls = function Controls(_ref) {
  var style = _ref.style,
      _ref$showZoom = _ref.showZoom,
      showZoom = _ref$showZoom === void 0 ? true : _ref$showZoom,
      _ref$showFitView = _ref.showFitView,
      showFitView = _ref$showFitView === void 0 ? true : _ref$showFitView,
      _ref$showInteractive = _ref.showInteractive,
      showInteractive = _ref$showInteractive === void 0 ? true : _ref$showInteractive,
      fitViewOptions = _ref.fitViewOptions,
      onZoomIn = _ref.onZoomIn,
      onZoomOut = _ref.onZoomOut,
      onFitView = _ref.onFitView,
      onInteractiveChange = _ref.onInteractiveChange,
      className = _ref.className,
      children = _ref.children,
      _ref$position = _ref.position,
      position = _ref$position === void 0 ? 'bottom-left' : _ref$position;
  var store = useStoreApi();

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isVisible = _useState2[0],
      setIsVisible = _useState2[1];

  var isInteractive = useStore(isInteractiveSelector);

  var _useReactFlow = useReactFlow(),
      zoomIn = _useReactFlow.zoomIn,
      zoomOut = _useReactFlow.zoomOut,
      fitView = _useReactFlow.fitView;

  useEffect(function () {
    setIsVisible(true);
  }, []);

  if (!isVisible) {
    return null;
  }

  var onZoomInHandler = function onZoomInHandler() {
    zoomIn();
    onZoomIn === null || onZoomIn === void 0 ? void 0 : onZoomIn();
  };

  var onZoomOutHandler = function onZoomOutHandler() {
    zoomOut();
    onZoomOut === null || onZoomOut === void 0 ? void 0 : onZoomOut();
  };

  var onFitViewHandler = function onFitViewHandler() {
    fitView(fitViewOptions);
    onFitView === null || onFitView === void 0 ? void 0 : onFitView();
  };

  var onToggleInteractivity = function onToggleInteractivity() {
    store.setState({
      nodesDraggable: !isInteractive,
      nodesConnectable: !isInteractive,
      elementsSelectable: !isInteractive
    });
    onInteractiveChange === null || onInteractiveChange === void 0 ? void 0 : onInteractiveChange(!isInteractive);
  };

  return /*#__PURE__*/jsxs(Panel, {
    className: cc(['react-flow__controls', className]),
    position: position,
    style: style,
    children: [showZoom && /*#__PURE__*/jsxs(Fragment, {
      children: [/*#__PURE__*/jsx(ControlButton$1, {
        onClick: onZoomInHandler,
        className: "react-flow__controls-zoomin",
        title: "zoom in",
        "aria-label": "zoom in",
        children: /*#__PURE__*/jsx(PlusIcon, {})
      }), /*#__PURE__*/jsx(ControlButton$1, {
        onClick: onZoomOutHandler,
        className: "react-flow__controls-zoomout",
        title: "zoom out",
        "aria-label": "zoom out",
        children: /*#__PURE__*/jsx(MinusIcon, {})
      })]
    }), showFitView && /*#__PURE__*/jsx(ControlButton$1, {
      className: "react-flow__controls-fitview",
      onClick: onFitViewHandler,
      title: "fit view",
      "aria-label": "fit view",
      children: /*#__PURE__*/jsx(FitViewIcon, {})
    }), showInteractive && /*#__PURE__*/jsx(ControlButton$1, {
      className: "react-flow__controls-interactive",
      onClick: onToggleInteractivity,
      title: "toggle interactivity",
      "aria-label": "toggle interactivity",
      children: isInteractive ? /*#__PURE__*/jsx(UnlockIcon, {}) : /*#__PURE__*/jsx(LockIcon, {})
    }), children]
  });
};

Controls.displayName = 'Controls';
var Controls$1 = /*#__PURE__*/memo(Controls);

export { ControlButton$1 as ControlButton, Controls$1 as Controls };
